@@ -71,20 +71,19 @@ pad <- function(x,
                 by        = NULL,
                 group     = NULL){
 
+  # this is preferred over as.list(match.call()) because of magrittr
+  pad_args <- list(x         = x,
+                   interval  = interval,
+                   start_val = start_val,
+                   end_val   = end_val,
+                   by        = by,
+                   group     = group)
+
+
   if (is.null(group)) {
-    pad_single(x,
-               interval  = interval,
-               start_val = start_val,
-               end_val   = end_val,
-               by        = by,
-               group     = NULL)
+    do.call(pad_single, pad_args)
   } else {
-    pad_multiple(x,
-                 interval  = interval,
-                 start_val = start_val,
-                 end_val   = end_val,
-                 by        = by,
-                 group     = group)
+    do.call(pad_multiple, pad_args)
   }
 }
 
@@ -198,8 +197,8 @@ pad_single  <- function(x,
   return(return_frame)
 }
 
-# This is the wrapper around pad_single, it will apply it on each of the
-# groups using dplyr.
+# This is the wrapper around pad_single
+
 pad_multiple <- function(x,
                          interval  = NULL,
                          start_val = NULL,
@@ -214,6 +213,7 @@ pad_multiple <- function(x,
   groupings <- unique(x[, colnames(x) %in% group, drop = FALSE])
   padded_groups <- vector("list", nrow(groupings))
 
+
   for (i in 1:nrow(groupings)){
 
     indic_mat <- matrix(0, nrow(x), ncol(groupings))
@@ -225,16 +225,18 @@ pad_multiple <- function(x,
     x_iter <- x[rowSums(indic_mat) == ncol(groupings), ]
 
     # because we span a data frame with the grouping vars included, we want to
-    # remove them from the data frame going into padr
+    # remove them from the data frame going into pad
 
-    padded_groups[[i]] <- pad_single(x_iter,
-                                     interval  = interval,
-                                     start_val = start_val,
-                                     end_val   = end_val,
-                                     by        = by,
-                                     group     = groupings[i, , drop = FALSE]) #nolint
+    pad_args <- list(x         = x_iter,
+                     interval  = interval,
+                     start_val = start_val,
+                     end_val   = end_val,
+                     by        = by,
+                     group     = groupings[i, , drop = FALSE]) # nolint
+
+    padded_groups[[i]] <- do.call(pad_single, pad_args)
   }
-  do.call("rbind", padded_groups)
+  return(do.call("rbind", padded_groups))
 }
 
 # when spanning for pad we want to allow for an end_val that is (far) after
